@@ -1,17 +1,37 @@
 //! Fixed-size arrays.
 
+use std::slice;
+
 /// Trait for fixed size arrays.
 pub unsafe trait Array {
     /// The array’s element type
     type Item;
+
     #[doc(hidden)]
     /// The smallest index type that indexes the array.
     type Index: Index;
-    #[doc(hidden)]
+
+    /// Returns a raw pointer to the slice's buffer.
     fn as_ptr(&self) -> *const Self::Item;
-    #[doc(hidden)]
+
+    /// Returns an unsafe mutable pointer to the slice's buffer.
     fn as_mut_ptr(&mut self) -> *mut Self::Item;
-    #[doc(hidden)]
+
+    /// Converts the array to immutable slice
+    #[inline(always)]
+    fn as_slice(&self) -> &[Self::Item] {
+        let ptr = self as *const _ as *const _;
+        unsafe { slice::from_raw_parts(ptr, Self::capacity()) }
+    }
+
+    /// Converts the array to mutable slice
+    #[inline(always)]
+    fn as_mut_slice(&mut self) -> &mut [Self::Item] {
+        let ptr = self as *mut _ as *mut _;
+        unsafe { slice::from_raw_parts_mut(ptr, Self::capacity()) }
+    }
+
+    /// Returns number of element the array can hold
     fn capacity() -> usize;
 }
 
@@ -26,7 +46,7 @@ impl Index for u8 {
     fn to_usize(self) -> usize {
         self as usize
     }
-    
+
     #[inline(always)]
     fn from(ix: usize) -> Self {
         ix as u8
@@ -100,4 +120,4 @@ fix_array_impl_recursive!(u16, 256, 384, 512, 768, 1024, 2048, 4096, 8192, 16384
 
 // This array size doesn't exist on 16-bit
 #[cfg(any(target_pointer_width="32", target_pointer_width="64"))]
-fix_array_impl_recursive!(u32, 1 << 16,);
\ No newline at end of file
+fix_array_impl_recursive!(u32, 1 << 16,);
