@@ -63,7 +63,6 @@ use std::hash::{Hash, Hasher};
 use std::marker;
 use std::fmt;
 use std::ptr;
-use std::slice;
 use std::iter::FromIterator;
 use std::ops::Index;
 use std::ops::IndexMut;
@@ -985,16 +984,6 @@ impl<A: Array, B: Behavior> ArrayDeque<A, B> {
         }
     }
 
-    #[inline]
-    unsafe fn buffer_as_slice(&self) -> &[A::Item] {
-        slice::from_raw_parts(self.ptr(), A::capacity())
-    }
-
-    #[inline]
-    unsafe fn buffer_as_mut_slice(&mut self) -> &mut [A::Item] {
-        slice::from_raw_parts_mut(self.ptr_mut(), A::capacity())
-    }
-
     #[inline]
     unsafe fn buffer_read(&mut self, offset: usize) -> A::Item {
         ptr::read(self.ptr().offset(offset as isize))
@@ -1299,7 +1288,7 @@ impl<A: Array, B: Behavior> ArrayDeque<A, B> {
         Iter {
             tail: self.tail(),
             len: self.len(),
-            ring: unsafe { self.buffer_as_slice() },
+            ring: self.xs.as_slice(),
         }
     }
 
@@ -1325,7 +1314,7 @@ impl<A: Array, B: Behavior> ArrayDeque<A, B> {
         IterMut {
             tail: self.tail(),
             len: self.len(),
-            ring: unsafe { self.buffer_as_mut_slice() },
+            ring: self.xs.as_mut_slice(),
         }
     }
 
@@ -1467,7 +1456,7 @@ impl<A: Array, B: Behavior> ArrayDeque<A, B> {
             iter: Iter {
                 tail: drain_tail,
                 len: drain_len,
-                ring: unsafe { self.buffer_as_mut_slice() },
+                ring: self.xs.as_mut_slice(),
             },
         }
     }
@@ -1929,21 +1918,19 @@ impl<A: Array, B: Behavior> ArrayDeque<A, B> {
     /// ```
     #[inline]
     pub fn as_mut_slices(&mut self) -> (&mut [A::Item], &mut [A::Item]) {
-        unsafe {
-            let contiguous = self.is_contiguous();
-            let head = self.head();
-            let tail = self.tail();
-            let buf = self.buffer_as_mut_slice();
+        let contiguous = self.is_contiguous();
+        let head = self.head();
+        let tail = self.tail();
+        let buf = self.xs.as_mut_slice();
 
-            if contiguous {
-                let (empty, buf) = buf.split_at_mut(0);
-                (&mut buf[tail..head], empty)
-            } else {
-                let (mid, right) = buf.split_at_mut(tail);
-                let (left, _) = mid.split_at_mut(head);
+        if contiguous {
+            let (empty, buf) = buf.split_at_mut(0);
+            (&mut buf[tail..head], empty)
+        } else {
+            let (mid, right) = buf.split_at_mut(tail);
+            let (left, _) = mid.split_at_mut(head);
 
-                (right, left)
-            }
+            (right, left)
         }
     }
 }
